@@ -4,6 +4,10 @@ CROMO_DEFAULT_PATH = "/tmp/cromo/"
 CROMO_DIR = "/tmp/cromo/"
 LOG_FILE = "log.txt"
 
+RULES_DIR = "src/cromo/resources/rules"
+ONTOLOGY_DIR = "src/cromo/resources/ontology"
+EXECUTION_ONTOLOGY_URL = "https://w3id.org/mint/execution.owl"
+
 DEFAULT_USERNAME = f"mint@isi.edu"
 #MODEL_CATALOG_URL = f"https://api.models.wildfire.mint.isi.edu/v1.7.0"
 MODEL_CATALOG_URL = f"https://api.models.mint.isi.edu/v1.7.0"
